@@ -248,7 +248,8 @@ AjPTrn ajTrnNewC(const char * filename)
 /* @func ajTrnNewI ************************************************************
 **
 ** Initialises translation. Reads a translation data file called 'EGC.x'
-** where 'x' is supplied as an ajint parameter in the range 0 to 15.
+** where 'x' is supplied as an ajint parameter.
+** The filename must exist somewhere in the data path.
 ** ajTrnDel should be called when translation has ceased.
 **
 ** @param [r] trnFileNameInt [ajint] translation table file name number
@@ -306,7 +307,7 @@ AjPTrn ajTrnNew(const AjPStr trnFileName)
 	trnFileName = ajStrNewC(TGCFILE);
 
 
-    ajFileDataNew(trnFileName, &trnFile);
+    trnFile = ajDatafileNewInNameS(trnFileName);
     if(trnFile==NULL)
 	ajFatal("Translation table file '%S' not found\n", trnFileName);
 
@@ -381,7 +382,7 @@ void ajTrnReadFile(AjPTrn trnObj, AjPFile trnFile)
 
     ajDebug("ajTrnReadFile %F\n", trnFile);
 
-    while(ajFileReadLine(trnFile, &trnLine))
+    while(ajReadlineTrim(trnFile, &trnLine))
     {
 	trnNoComment(&trnLine);
 	if(ajStrGetLen(trnLine))
@@ -396,7 +397,7 @@ void ajTrnReadFile(AjPTrn trnObj, AjPFile trnFile)
     }
 
     /* title */
-    while(ajFileReadLine(trnFile, &trnLine))
+    while(ajReadlineTrim(trnFile, &trnLine))
     {
 	trnNoComment(&trnLine);
 	if(ajStrGetLen(trnLine))
@@ -407,7 +408,7 @@ void ajTrnReadFile(AjPTrn trnObj, AjPFile trnFile)
     }
 
     /* rest */
-    while(ajFileReadLine(trnFile, &trnLine))
+    while(ajReadlineTrim(trnFile, &trnLine))
     {
 	trnNoComment(&trnLine);
 	if(ajStrGetLen(trnLine))
@@ -1654,11 +1655,11 @@ const AjPStr ajTrnName(ajint trnFileNameInt)
 	    indexfname = ajStrNewC("EGC.index");
 	trnCodes = ajTablestrNewLen(20);
 
-	ajFileDataNew(indexfname, &indexf);
+	indexf = ajDatafileNewInNameS(indexfname);
 	if(!indexf)
 	    return unknown;
 
-	while(ajFileReadLine(indexf, &line))
+	while(ajReadlineTrim(indexf, &line))
 	{
 	    ajStrTrimWhite(&line);
 	    if(ajStrGetCharFirst(line) == '#')
